@@ -285,13 +285,38 @@ arma_inline
 void
 arma_ostream::print_elem(std::ostream& o, const eT& x, const bool modify)
   {
-  if(x != eT(0))
+  if(is_signed<eT>::value)
     {
-    o << x;
+    typedef typename promote_type<eT, s16>::result promoted_eT;
+    
+    if(x != eT(0))
+      {
+      if(arma_isfinite(x))
+        {
+        o << promoted_eT(x);
+        }
+      else
+        {
+        o << ( arma_isinf(x) ? ((x <= eT(0)) ? "-inf" : "inf") : "nan" );
+        }
+      }
+    else
+      {
+      arma_ostream::print_elem_zero<promoted_eT>(o, modify);
+      }
     }
   else
     {
-    arma_ostream::print_elem_zero<eT>(o, modify);
+    typedef typename promote_type<eT, u16>::result promoted_eT;
+    
+    if(x != eT(0))
+      {
+      o << promoted_eT(x);
+      }
+    else
+      {
+      arma_ostream::print_elem_zero<promoted_eT>(o, modify);
+      }
     }
   }
 
@@ -309,8 +334,35 @@ arma_ostream::print_elem(std::ostream& o, const std::complex<T>& x, const bool m
     ss.flags(o.flags());
     //ss.imbue(o.getloc());
     ss.precision(o.precision());
-  
-    ss << '(' << x.real() << ',' << x.imag() << ')';
+    
+    ss << '(';
+    
+    const T a = x.real();
+    
+    if(arma_isfinite(a))
+      {
+      ss << a;
+      }
+    else
+      {
+      ss << ( arma_isinf(a) ? ((a <= T(0)) ? "-inf" : "+inf") : "nan" );
+      }
+    
+    ss << ',';
+    
+    const T b = x.imag();
+    
+    if(arma_isfinite(b))
+      {
+      ss << b;
+      }
+    else
+      {
+      ss << ( arma_isinf(b) ? ((b <= T(0)) ? "-inf" : "+inf") : "nan" );
+      }
+    
+    ss << ')';
+    
     o << ss.str();
     }
   else
@@ -732,7 +784,7 @@ arma_ostream::print(std::ostream& o, const SizeMat& S)
   
   o.setf(ios::fixed);
   
-  o << S.n_rows << 'x' << S.n_cols << '\n';
+  o << S.n_rows << 'x' << S.n_cols;
   
   stream_state.restore(o);
   }
@@ -753,7 +805,7 @@ arma_ostream::print(std::ostream& o, const SizeCube& S)
   
   o.setf(ios::fixed);
     
-  o << S.n_rows << 'x' << S.n_cols << 'x' << S.n_slices << '\n';
+  o << S.n_rows << 'x' << S.n_cols << 'x' << S.n_slices;
   
   stream_state.restore(o);
   }
